@@ -37,6 +37,7 @@ impl From<crate::W<CH_AL2_CTRL_SPEC>> for W {
 #[doc = "Field `AHB_ERROR` reader - Logical OR of the READ_ERROR and WRITE_ERROR flags. The channel halts when it encounters any bus error, and always raises its channel IRQ flag."]
 pub struct AHB_ERROR_R(crate::FieldReader<bool, bool>);
 impl AHB_ERROR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         AHB_ERROR_R(crate::FieldReader::new(bits))
     }
@@ -52,6 +53,7 @@ impl core::ops::Deref for AHB_ERROR_R {
  READ_ADDR shows the approximate address where the bus error was encountered (will not to be earlier, or more than 3 transfers later)"]
 pub struct READ_ERROR_R(crate::FieldReader<bool, bool>);
 impl READ_ERROR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         READ_ERROR_R(crate::FieldReader::new(bits))
     }
@@ -90,6 +92,7 @@ impl<'a> READ_ERROR_W<'a> {
  WRITE_ADDR shows the approximate address where the bus error was encountered (will not to be earlier, or more than 5 transfers later)"]
 pub struct WRITE_ERROR_R(crate::FieldReader<bool, bool>);
 impl WRITE_ERROR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         WRITE_ERROR_R(crate::FieldReader::new(bits))
     }
@@ -129,6 +132,7 @@ impl<'a> WRITE_ERROR_W<'a> {
  To terminate a sequence early (and clear the BUSY flag), see CHAN_ABORT."]
 pub struct BUSY_R(crate::FieldReader<bool, bool>);
 impl BUSY_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         BUSY_R(crate::FieldReader::new(bits))
     }
@@ -145,6 +149,7 @@ impl core::ops::Deref for BUSY_R {
  This allows checksum to be enabled or disabled on a per-control- block basis."]
 pub struct SNIFF_EN_R(crate::FieldReader<bool, bool>);
 impl SNIFF_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SNIFF_EN_R(crate::FieldReader::new(bits))
     }
@@ -184,6 +189,7 @@ impl<'a> SNIFF_EN_W<'a> {
  For byte data, this has no effect. For halfword data, the two bytes of each halfword are swapped. For word data, the four bytes of each word are swapped to reverse order."]
 pub struct BSWAP_R(crate::FieldReader<bool, bool>);
 impl BSWAP_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         BSWAP_R(crate::FieldReader::new(bits))
     }
@@ -223,6 +229,7 @@ impl<'a> BSWAP_W<'a> {
  This reduces the number of interrupts to be serviced by the CPU when transferring a DMA chain of many small control blocks."]
 pub struct IRQ_QUIET_R(crate::FieldReader<bool, bool>);
 impl IRQ_QUIET_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         IRQ_QUIET_R(crate::FieldReader::new(bits))
     }
@@ -288,6 +295,7 @@ impl From<TREQ_SEL_A> for u8 {
  0x0 to 0x3a -> select DREQ n as TREQ"]
 pub struct TREQ_SEL_R(crate::FieldReader<u8, TREQ_SEL_A>);
 impl TREQ_SEL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         TREQ_SEL_R(crate::FieldReader::new(bits))
     }
@@ -384,6 +392,7 @@ impl<'a> TREQ_SEL_W<'a> {
  Reset value is equal to channel number (0)."]
 pub struct CHAIN_TO_R(crate::FieldReader<u8, u8>);
 impl CHAIN_TO_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         CHAIN_TO_R(crate::FieldReader::new(bits))
     }
@@ -412,6 +421,7 @@ impl<'a> CHAIN_TO_W<'a> {
  If 0, read addresses are wrapped on a (1 << RING_SIZE) boundary. If 1, write addresses are wrapped."]
 pub struct RING_SEL_R(crate::FieldReader<bool, bool>);
 impl RING_SEL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         RING_SEL_R(crate::FieldReader::new(bits))
     }
@@ -468,6 +478,7 @@ impl From<RING_SIZE_A> for u8 {
  Ring sizes between 2 and 32768 bytes are possible. This can apply to either read or write addresses, based on value of RING_SEL."]
 pub struct RING_SIZE_R(crate::FieldReader<u8, RING_SIZE_A>);
 impl RING_SIZE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         RING_SIZE_R(crate::FieldReader::new(bits))
     }
@@ -521,6 +532,7 @@ impl<'a> RING_SIZE_W<'a> {
  Generally this should be disabled for memory-to-peripheral transfers."]
 pub struct INCR_WRITE_R(crate::FieldReader<bool, bool>);
 impl INCR_WRITE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         INCR_WRITE_R(crate::FieldReader::new(bits))
     }
@@ -561,6 +573,7 @@ impl<'a> INCR_WRITE_W<'a> {
  Generally this should be disabled for peripheral-to-memory transfers."]
 pub struct INCR_READ_R(crate::FieldReader<bool, bool>);
 impl INCR_READ_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         INCR_READ_R(crate::FieldReader::new(bits))
     }
@@ -618,6 +631,7 @@ impl From<DATA_SIZE_A> for u8 {
 #[doc = "Field `DATA_SIZE` reader - Set the size of each bus transfer (byte/halfword/word). READ_ADDR and WRITE_ADDR advance by this amount (1/2/4 bytes) with each transfer."]
 pub struct DATA_SIZE_R(crate::FieldReader<u8, DATA_SIZE_A>);
 impl DATA_SIZE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         DATA_SIZE_R(crate::FieldReader::new(bits))
     }
@@ -691,6 +705,7 @@ impl<'a> DATA_SIZE_W<'a> {
  This only affects the order in which the DMA schedules channels. The DMA's bus priority is not changed. If the DMA is not saturated then a low priority channel will see no loss of throughput."]
 pub struct HIGH_PRIORITY_R(crate::FieldReader<bool, bool>);
 impl HIGH_PRIORITY_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         HIGH_PRIORITY_R(crate::FieldReader::new(bits))
     }
@@ -730,6 +745,7 @@ impl<'a> HIGH_PRIORITY_W<'a> {
  When 1, the channel will respond to triggering events, which will cause it to become BUSY and start transferring data. When 0, the channel will ignore triggers, stop issuing transfers, and pause the current transfer sequence (i.e. BUSY will remain high if already high)"]
 pub struct EN_R(crate::FieldReader<bool, bool>);
 impl EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         EN_R(crate::FieldReader::new(bits))
     }
@@ -770,62 +786,81 @@ impl R {
     pub fn ahb_error(&self) -> AHB_ERROR_R {
         AHB_ERROR_R::new(((self.bits >> 31) & 0x01) != 0)
     }
-    #[doc = "Bit 30 - If 1, the channel received a read bus error. Write one to clear. READ_ADDR shows the approximate address where the bus error was encountered (will not to be earlier, or more than 3 transfers later)"]
+    #[doc = "Bit 30 - If 1, the channel received a read bus error. Write one to clear.  
+ READ_ADDR shows the approximate address where the bus error was encountered (will not to be earlier, or more than 3 transfers later)"]
     #[inline(always)]
     pub fn read_error(&self) -> READ_ERROR_R {
         READ_ERROR_R::new(((self.bits >> 30) & 0x01) != 0)
     }
-    #[doc = "Bit 29 - If 1, the channel received a write bus error. Write one to clear. WRITE_ADDR shows the approximate address where the bus error was encountered (will not to be earlier, or more than 5 transfers later)"]
+    #[doc = "Bit 29 - If 1, the channel received a write bus error. Write one to clear.  
+ WRITE_ADDR shows the approximate address where the bus error was encountered (will not to be earlier, or more than 5 transfers later)"]
     #[inline(always)]
     pub fn write_error(&self) -> WRITE_ERROR_R {
         WRITE_ERROR_R::new(((self.bits >> 29) & 0x01) != 0)
     }
-    #[doc = "Bit 24 - This flag goes high when the channel starts a new transfer sequence, and low when the last transfer of that sequence completes. Clearing EN while BUSY is high pauses the channel, and BUSY will stay high while paused. To terminate a sequence early (and clear the BUSY flag), see CHAN_ABORT."]
+    #[doc = "Bit 24 - This flag goes high when the channel starts a new transfer sequence, and low when the last transfer of that sequence completes. Clearing EN while BUSY is high pauses the channel, and BUSY will stay high while paused.  
+
+ To terminate a sequence early (and clear the BUSY flag), see CHAN_ABORT."]
     #[inline(always)]
     pub fn busy(&self) -> BUSY_R {
         BUSY_R::new(((self.bits >> 24) & 0x01) != 0)
     }
-    #[doc = "Bit 23 - If 1, this channel's data transfers are visible to the sniff hardware, and each transfer will advance the state of the checksum. This only applies if the sniff hardware is enabled, and has this channel selected. This allows checksum to be enabled or disabled on a per-control- block basis."]
+    #[doc = "Bit 23 - If 1, this channel's data transfers are visible to the sniff hardware, and each transfer will advance the state of the checksum. This only applies if the sniff hardware is enabled, and has this channel selected.  
+
+ This allows checksum to be enabled or disabled on a per-control- block basis."]
     #[inline(always)]
     pub fn sniff_en(&self) -> SNIFF_EN_R {
         SNIFF_EN_R::new(((self.bits >> 23) & 0x01) != 0)
     }
-    #[doc = "Bit 22 - Apply byte-swap transformation to DMA data. For byte data, this has no effect. For halfword data, the two bytes of each halfword are swapped. For word data, the four bytes of each word are swapped to reverse order."]
+    #[doc = "Bit 22 - Apply byte-swap transformation to DMA data.  
+ For byte data, this has no effect. For halfword data, the two bytes of each halfword are swapped. For word data, the four bytes of each word are swapped to reverse order."]
     #[inline(always)]
     pub fn bswap(&self) -> BSWAP_R {
         BSWAP_R::new(((self.bits >> 22) & 0x01) != 0)
     }
-    #[doc = "Bit 21 - In QUIET mode, the channel does not generate IRQs at the end of every transfer block. Instead, an IRQ is raised when NULL is written to a trigger register, indicating the end of a control block chain. This reduces the number of interrupts to be serviced by the CPU when transferring a DMA chain of many small control blocks."]
+    #[doc = "Bit 21 - In QUIET mode, the channel does not generate IRQs at the end of every transfer block. Instead, an IRQ is raised when NULL is written to a trigger register, indicating the end of a control block chain.  
+
+ This reduces the number of interrupts to be serviced by the CPU when transferring a DMA chain of many small control blocks."]
     #[inline(always)]
     pub fn irq_quiet(&self) -> IRQ_QUIET_R {
         IRQ_QUIET_R::new(((self.bits >> 21) & 0x01) != 0)
     }
-    #[doc = "Bits 15:20 - Select a Transfer Request signal. The channel uses the transfer request signal to pace its data transfer rate. Sources for TREQ signals are internal (TIMERS) or external (DREQ, a Data Request from the system). 0x0 to 0x3a -> select DREQ n as TREQ"]
+    #[doc = "Bits 15:20 - Select a Transfer Request signal.  
+ The channel uses the transfer request signal to pace its data transfer rate. Sources for TREQ signals are internal (TIMERS) or external (DREQ, a Data Request from the system).  
+ 0x0 to 0x3a -> select DREQ n as TREQ"]
     #[inline(always)]
     pub fn treq_sel(&self) -> TREQ_SEL_R {
         TREQ_SEL_R::new(((self.bits >> 15) & 0x3f) as u8)
     }
-    #[doc = "Bits 11:14 - When this channel completes, it will trigger the channel indicated by CHAIN_TO. Disable by setting CHAIN_TO = _(this channel)_. Reset value is equal to channel number (0)."]
+    #[doc = "Bits 11:14 - When this channel completes, it will trigger the channel indicated by CHAIN_TO. Disable by setting CHAIN_TO = _(this channel)_.  
+ Reset value is equal to channel number (0)."]
     #[inline(always)]
     pub fn chain_to(&self) -> CHAIN_TO_R {
         CHAIN_TO_R::new(((self.bits >> 11) & 0x0f) as u8)
     }
-    #[doc = "Bit 10 - Select whether RING_SIZE applies to read or write addresses. If 0, read addresses are wrapped on a (1 << RING_SIZE) boundary. If 1, write addresses are wrapped."]
+    #[doc = "Bit 10 - Select whether RING_SIZE applies to read or write addresses.  
+ If 0, read addresses are wrapped on a (1 << RING_SIZE) boundary. If 1, write addresses are wrapped."]
     #[inline(always)]
     pub fn ring_sel(&self) -> RING_SEL_R {
         RING_SEL_R::new(((self.bits >> 10) & 0x01) != 0)
     }
-    #[doc = "Bits 6:9 - Size of address wrap region. If 0, don't wrap. For values n > 0, only the lower n bits of the address will change. This wraps the address on a (1 << n) byte boundary, facilitating access to naturally-aligned ring buffers. Ring sizes between 2 and 32768 bytes are possible. This can apply to either read or write addresses, based on value of RING_SEL."]
+    #[doc = "Bits 6:9 - Size of address wrap region. If 0, don't wrap. For values n > 0, only the lower n bits of the address will change. This wraps the address on a (1 << n) byte boundary, facilitating access to naturally-aligned ring buffers.  
+
+ Ring sizes between 2 and 32768 bytes are possible. This can apply to either read or write addresses, based on value of RING_SEL."]
     #[inline(always)]
     pub fn ring_size(&self) -> RING_SIZE_R {
         RING_SIZE_R::new(((self.bits >> 6) & 0x0f) as u8)
     }
-    #[doc = "Bit 5 - If 1, the write address increments with each transfer. If 0, each write is directed to the same, initial address. Generally this should be disabled for memory-to-peripheral transfers."]
+    #[doc = "Bit 5 - If 1, the write address increments with each transfer. If 0, each write is directed to the same, initial address.  
+
+ Generally this should be disabled for memory-to-peripheral transfers."]
     #[inline(always)]
     pub fn incr_write(&self) -> INCR_WRITE_R {
         INCR_WRITE_R::new(((self.bits >> 5) & 0x01) != 0)
     }
-    #[doc = "Bit 4 - If 1, the read address increments with each transfer. If 0, each read is directed to the same, initial address. Generally this should be disabled for peripheral-to-memory transfers."]
+    #[doc = "Bit 4 - If 1, the read address increments with each transfer. If 0, each read is directed to the same, initial address.  
+
+ Generally this should be disabled for peripheral-to-memory transfers."]
     #[inline(always)]
     pub fn incr_read(&self) -> INCR_READ_R {
         INCR_READ_R::new(((self.bits >> 4) & 0x01) != 0)
@@ -835,69 +870,89 @@ impl R {
     pub fn data_size(&self) -> DATA_SIZE_R {
         DATA_SIZE_R::new(((self.bits >> 2) & 0x03) as u8)
     }
-    #[doc = "Bit 1 - HIGH_PRIORITY gives a channel preferential treatment in issue scheduling: in each scheduling round, all high priority channels are considered first, and then only a single low priority channel, before returning to the high priority channels. This only affects the order in which the DMA schedules channels. The DMA's bus priority is not changed. If the DMA is not saturated then a low priority channel will see no loss of throughput."]
+    #[doc = "Bit 1 - HIGH_PRIORITY gives a channel preferential treatment in issue scheduling: in each scheduling round, all high priority channels are considered first, and then only a single low priority channel, before returning to the high priority channels.  
+
+ This only affects the order in which the DMA schedules channels. The DMA's bus priority is not changed. If the DMA is not saturated then a low priority channel will see no loss of throughput."]
     #[inline(always)]
     pub fn high_priority(&self) -> HIGH_PRIORITY_R {
         HIGH_PRIORITY_R::new(((self.bits >> 1) & 0x01) != 0)
     }
-    #[doc = "Bit 0 - DMA Channel Enable. When 1, the channel will respond to triggering events, which will cause it to become BUSY and start transferring data. When 0, the channel will ignore triggers, stop issuing transfers, and pause the current transfer sequence (i.e. BUSY will remain high if already high)"]
+    #[doc = "Bit 0 - DMA Channel Enable.  
+ When 1, the channel will respond to triggering events, which will cause it to become BUSY and start transferring data. When 0, the channel will ignore triggers, stop issuing transfers, and pause the current transfer sequence (i.e. BUSY will remain high if already high)"]
     #[inline(always)]
     pub fn en(&self) -> EN_R {
         EN_R::new((self.bits & 0x01) != 0)
     }
 }
 impl W {
-    #[doc = "Bit 30 - If 1, the channel received a read bus error. Write one to clear. READ_ADDR shows the approximate address where the bus error was encountered (will not to be earlier, or more than 3 transfers later)"]
+    #[doc = "Bit 30 - If 1, the channel received a read bus error. Write one to clear.  
+ READ_ADDR shows the approximate address where the bus error was encountered (will not to be earlier, or more than 3 transfers later)"]
     #[inline(always)]
     pub fn read_error(&mut self) -> READ_ERROR_W {
         READ_ERROR_W { w: self }
     }
-    #[doc = "Bit 29 - If 1, the channel received a write bus error. Write one to clear. WRITE_ADDR shows the approximate address where the bus error was encountered (will not to be earlier, or more than 5 transfers later)"]
+    #[doc = "Bit 29 - If 1, the channel received a write bus error. Write one to clear.  
+ WRITE_ADDR shows the approximate address where the bus error was encountered (will not to be earlier, or more than 5 transfers later)"]
     #[inline(always)]
     pub fn write_error(&mut self) -> WRITE_ERROR_W {
         WRITE_ERROR_W { w: self }
     }
-    #[doc = "Bit 23 - If 1, this channel's data transfers are visible to the sniff hardware, and each transfer will advance the state of the checksum. This only applies if the sniff hardware is enabled, and has this channel selected. This allows checksum to be enabled or disabled on a per-control- block basis."]
+    #[doc = "Bit 23 - If 1, this channel's data transfers are visible to the sniff hardware, and each transfer will advance the state of the checksum. This only applies if the sniff hardware is enabled, and has this channel selected.  
+
+ This allows checksum to be enabled or disabled on a per-control- block basis."]
     #[inline(always)]
     pub fn sniff_en(&mut self) -> SNIFF_EN_W {
         SNIFF_EN_W { w: self }
     }
-    #[doc = "Bit 22 - Apply byte-swap transformation to DMA data. For byte data, this has no effect. For halfword data, the two bytes of each halfword are swapped. For word data, the four bytes of each word are swapped to reverse order."]
+    #[doc = "Bit 22 - Apply byte-swap transformation to DMA data.  
+ For byte data, this has no effect. For halfword data, the two bytes of each halfword are swapped. For word data, the four bytes of each word are swapped to reverse order."]
     #[inline(always)]
     pub fn bswap(&mut self) -> BSWAP_W {
         BSWAP_W { w: self }
     }
-    #[doc = "Bit 21 - In QUIET mode, the channel does not generate IRQs at the end of every transfer block. Instead, an IRQ is raised when NULL is written to a trigger register, indicating the end of a control block chain. This reduces the number of interrupts to be serviced by the CPU when transferring a DMA chain of many small control blocks."]
+    #[doc = "Bit 21 - In QUIET mode, the channel does not generate IRQs at the end of every transfer block. Instead, an IRQ is raised when NULL is written to a trigger register, indicating the end of a control block chain.  
+
+ This reduces the number of interrupts to be serviced by the CPU when transferring a DMA chain of many small control blocks."]
     #[inline(always)]
     pub fn irq_quiet(&mut self) -> IRQ_QUIET_W {
         IRQ_QUIET_W { w: self }
     }
-    #[doc = "Bits 15:20 - Select a Transfer Request signal. The channel uses the transfer request signal to pace its data transfer rate. Sources for TREQ signals are internal (TIMERS) or external (DREQ, a Data Request from the system). 0x0 to 0x3a -> select DREQ n as TREQ"]
+    #[doc = "Bits 15:20 - Select a Transfer Request signal.  
+ The channel uses the transfer request signal to pace its data transfer rate. Sources for TREQ signals are internal (TIMERS) or external (DREQ, a Data Request from the system).  
+ 0x0 to 0x3a -> select DREQ n as TREQ"]
     #[inline(always)]
     pub fn treq_sel(&mut self) -> TREQ_SEL_W {
         TREQ_SEL_W { w: self }
     }
-    #[doc = "Bits 11:14 - When this channel completes, it will trigger the channel indicated by CHAIN_TO. Disable by setting CHAIN_TO = _(this channel)_. Reset value is equal to channel number (0)."]
+    #[doc = "Bits 11:14 - When this channel completes, it will trigger the channel indicated by CHAIN_TO. Disable by setting CHAIN_TO = _(this channel)_.  
+ Reset value is equal to channel number (0)."]
     #[inline(always)]
     pub fn chain_to(&mut self) -> CHAIN_TO_W {
         CHAIN_TO_W { w: self }
     }
-    #[doc = "Bit 10 - Select whether RING_SIZE applies to read or write addresses. If 0, read addresses are wrapped on a (1 << RING_SIZE) boundary. If 1, write addresses are wrapped."]
+    #[doc = "Bit 10 - Select whether RING_SIZE applies to read or write addresses.  
+ If 0, read addresses are wrapped on a (1 << RING_SIZE) boundary. If 1, write addresses are wrapped."]
     #[inline(always)]
     pub fn ring_sel(&mut self) -> RING_SEL_W {
         RING_SEL_W { w: self }
     }
-    #[doc = "Bits 6:9 - Size of address wrap region. If 0, don't wrap. For values n > 0, only the lower n bits of the address will change. This wraps the address on a (1 << n) byte boundary, facilitating access to naturally-aligned ring buffers. Ring sizes between 2 and 32768 bytes are possible. This can apply to either read or write addresses, based on value of RING_SEL."]
+    #[doc = "Bits 6:9 - Size of address wrap region. If 0, don't wrap. For values n > 0, only the lower n bits of the address will change. This wraps the address on a (1 << n) byte boundary, facilitating access to naturally-aligned ring buffers.  
+
+ Ring sizes between 2 and 32768 bytes are possible. This can apply to either read or write addresses, based on value of RING_SEL."]
     #[inline(always)]
     pub fn ring_size(&mut self) -> RING_SIZE_W {
         RING_SIZE_W { w: self }
     }
-    #[doc = "Bit 5 - If 1, the write address increments with each transfer. If 0, each write is directed to the same, initial address. Generally this should be disabled for memory-to-peripheral transfers."]
+    #[doc = "Bit 5 - If 1, the write address increments with each transfer. If 0, each write is directed to the same, initial address.  
+
+ Generally this should be disabled for memory-to-peripheral transfers."]
     #[inline(always)]
     pub fn incr_write(&mut self) -> INCR_WRITE_W {
         INCR_WRITE_W { w: self }
     }
-    #[doc = "Bit 4 - If 1, the read address increments with each transfer. If 0, each read is directed to the same, initial address. Generally this should be disabled for peripheral-to-memory transfers."]
+    #[doc = "Bit 4 - If 1, the read address increments with each transfer. If 0, each read is directed to the same, initial address.  
+
+ Generally this should be disabled for peripheral-to-memory transfers."]
     #[inline(always)]
     pub fn incr_read(&mut self) -> INCR_READ_W {
         INCR_READ_W { w: self }
@@ -907,12 +962,15 @@ impl W {
     pub fn data_size(&mut self) -> DATA_SIZE_W {
         DATA_SIZE_W { w: self }
     }
-    #[doc = "Bit 1 - HIGH_PRIORITY gives a channel preferential treatment in issue scheduling: in each scheduling round, all high priority channels are considered first, and then only a single low priority channel, before returning to the high priority channels. This only affects the order in which the DMA schedules channels. The DMA's bus priority is not changed. If the DMA is not saturated then a low priority channel will see no loss of throughput."]
+    #[doc = "Bit 1 - HIGH_PRIORITY gives a channel preferential treatment in issue scheduling: in each scheduling round, all high priority channels are considered first, and then only a single low priority channel, before returning to the high priority channels.  
+
+ This only affects the order in which the DMA schedules channels. The DMA's bus priority is not changed. If the DMA is not saturated then a low priority channel will see no loss of throughput."]
     #[inline(always)]
     pub fn high_priority(&mut self) -> HIGH_PRIORITY_W {
         HIGH_PRIORITY_W { w: self }
     }
-    #[doc = "Bit 0 - DMA Channel Enable. When 1, the channel will respond to triggering events, which will cause it to become BUSY and start transferring data. When 0, the channel will ignore triggers, stop issuing transfers, and pause the current transfer sequence (i.e. BUSY will remain high if already high)"]
+    #[doc = "Bit 0 - DMA Channel Enable.  
+ When 1, the channel will respond to triggering events, which will cause it to become BUSY and start transferring data. When 0, the channel will ignore triggers, stop issuing transfers, and pause the current transfer sequence (i.e. BUSY will remain high if already high)"]
     #[inline(always)]
     pub fn en(&mut self) -> EN_W {
         EN_W { w: self }
