@@ -39,6 +39,7 @@ impl From<crate::W<IC_DMA_RDLR_SPEC>> for W {
  Reset value: 0x0"]
 pub struct DMARDL_R(crate::FieldReader<u8, u8>);
 impl DMARDL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         DMARDL_R(crate::FieldReader::new(bits))
     }
@@ -65,14 +66,18 @@ impl<'a> DMARDL_W<'a> {
     }
 }
 impl R {
-    #[doc = "Bits 0:3 - Receive Data Level. This bit field controls the level at which a DMA request is made by the receive logic. The watermark level = DMARDL+1; that is, dma_rx_req is generated when the number of valid data entries in the receive FIFO is equal to or more than this field value + 1, and RDMAE =1. For instance, when DMARDL is 0, then dma_rx_req is asserted when 1 or more data entries are present in the receive FIFO. Reset value: 0x0"]
+    #[doc = "Bits 0:3 - Receive Data Level. This bit field controls the level at which a DMA request is made by the receive logic. The watermark level = DMARDL+1; that is, dma_rx_req is generated when the number of valid data entries in the receive FIFO is equal to or more than this field value + 1, and RDMAE =1. For instance, when DMARDL is 0, then dma_rx_req is asserted when 1 or more data entries are present in the receive FIFO.  
+
+ Reset value: 0x0"]
     #[inline(always)]
     pub fn dmardl(&self) -> DMARDL_R {
         DMARDL_R::new((self.bits & 0x0f) as u8)
     }
 }
 impl W {
-    #[doc = "Bits 0:3 - Receive Data Level. This bit field controls the level at which a DMA request is made by the receive logic. The watermark level = DMARDL+1; that is, dma_rx_req is generated when the number of valid data entries in the receive FIFO is equal to or more than this field value + 1, and RDMAE =1. For instance, when DMARDL is 0, then dma_rx_req is asserted when 1 or more data entries are present in the receive FIFO. Reset value: 0x0"]
+    #[doc = "Bits 0:3 - Receive Data Level. This bit field controls the level at which a DMA request is made by the receive logic. The watermark level = DMARDL+1; that is, dma_rx_req is generated when the number of valid data entries in the receive FIFO is equal to or more than this field value + 1, and RDMAE =1. For instance, when DMARDL is 0, then dma_rx_req is asserted when 1 or more data entries are present in the receive FIFO.  
+
+ Reset value: 0x0"]
     #[inline(always)]
     pub fn dmardl(&mut self) -> DMARDL_W {
         DMARDL_W { w: self }
