@@ -39,6 +39,7 @@ impl From<crate::W<IC_DMA_TDLR_SPEC>> for W {
  Reset value: 0x0"]
 pub struct DMATDL_R(crate::FieldReader<u8, u8>);
 impl DMATDL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         DMATDL_R(crate::FieldReader::new(bits))
     }
@@ -65,14 +66,18 @@ impl<'a> DMATDL_W<'a> {
     }
 }
 impl R {
-    #[doc = "Bits 0:3 - Transmit Data Level. This bit field controls the level at which a DMA request is made by the transmit logic. It is equal to the watermark level; that is, the dma_tx_req signal is generated when the number of valid data entries in the transmit FIFO is equal to or below this field value, and TDMAE = 1. Reset value: 0x0"]
+    #[doc = "Bits 0:3 - Transmit Data Level. This bit field controls the level at which a DMA request is made by the transmit logic. It is equal to the watermark level; that is, the dma_tx_req signal is generated when the number of valid data entries in the transmit FIFO is equal to or below this field value, and TDMAE = 1.  
+
+ Reset value: 0x0"]
     #[inline(always)]
     pub fn dmatdl(&self) -> DMATDL_R {
         DMATDL_R::new((self.bits & 0x0f) as u8)
     }
 }
 impl W {
-    #[doc = "Bits 0:3 - Transmit Data Level. This bit field controls the level at which a DMA request is made by the transmit logic. It is equal to the watermark level; that is, the dma_tx_req signal is generated when the number of valid data entries in the transmit FIFO is equal to or below this field value, and TDMAE = 1. Reset value: 0x0"]
+    #[doc = "Bits 0:3 - Transmit Data Level. This bit field controls the level at which a DMA request is made by the transmit logic. It is equal to the watermark level; that is, the dma_tx_req signal is generated when the number of valid data entries in the transmit FIFO is equal to or below this field value, and TDMAE = 1.  
+
+ Reset value: 0x0"]
     #[inline(always)]
     pub fn dmatdl(&mut self) -> DMATDL_W {
         DMATDL_W { w: self }
