@@ -44,6 +44,7 @@ register being set to 0. Writes at other times have no effect.
  The minimum valid value is 8; hardware prevents values less than this being written, and if attempted results in 8 being set. For designs with APB_DATA_WIDTH = 8 the order of programming is important to ensure the correct operation of the DW_apb_i2c. The lower byte must be programmed first. Then the upper byte is programmed. If the value is less than 8 then the count value gets changed to 8."]
 pub struct IC_FS_SCL_LCNT_R(crate::FieldReader<u16, u16>);
 impl IC_FS_SCL_LCNT_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u16) -> Self {
         IC_FS_SCL_LCNT_R(crate::FieldReader::new(bits))
     }
@@ -75,16 +76,28 @@ impl<'a> IC_FS_SCL_LCNT_W<'a> {
     }
 }
 impl R {
-    #[doc = "Bits 0:15 - This register must be set before any I2C bus transaction can take place to ensure proper I/O timing. This register sets the SCL clock low period count for fast speed. It is used in high-speed mode to send the Master Code and START BYTE or General CALL. For more information, refer to 'IC_CLK Frequency Configuration'. This register goes away and becomes read-only returning 0s if IC_MAX_SPEED_MODE = standard. This register can be written only when the I2C interface is disabled, which corresponds to the IC_ENABLE\\[0\\]
-register being set to 0. Writes at other times have no effect. The minimum valid value is 8; hardware prevents values less than this being written, and if attempted results in 8 being set. For designs with APB_DATA_WIDTH = 8 the order of programming is important to ensure the correct operation of the DW_apb_i2c. The lower byte must be programmed first. Then the upper byte is programmed. If the value is less than 8 then the count value gets changed to 8."]
+    #[doc = "Bits 0:15 - This register must be set before any I2C bus transaction can take place to ensure proper I/O timing. This register sets the SCL clock low period count for fast speed. It is used in high-speed mode to send the Master Code and START BYTE or General CALL. For more information, refer to 'IC_CLK Frequency Configuration'.  
+
+ This register goes away and becomes read-only returning 0s if IC_MAX_SPEED_MODE = standard.  
+
+ This register can be written only when the I2C interface is disabled, which corresponds to the IC_ENABLE\\[0\\]
+register being set to 0. Writes at other times have no effect.  
+
+ The minimum valid value is 8; hardware prevents values less than this being written, and if attempted results in 8 being set. For designs with APB_DATA_WIDTH = 8 the order of programming is important to ensure the correct operation of the DW_apb_i2c. The lower byte must be programmed first. Then the upper byte is programmed. If the value is less than 8 then the count value gets changed to 8."]
     #[inline(always)]
     pub fn ic_fs_scl_lcnt(&self) -> IC_FS_SCL_LCNT_R {
         IC_FS_SCL_LCNT_R::new((self.bits & 0xffff) as u16)
     }
 }
 impl W {
-    #[doc = "Bits 0:15 - This register must be set before any I2C bus transaction can take place to ensure proper I/O timing. This register sets the SCL clock low period count for fast speed. It is used in high-speed mode to send the Master Code and START BYTE or General CALL. For more information, refer to 'IC_CLK Frequency Configuration'. This register goes away and becomes read-only returning 0s if IC_MAX_SPEED_MODE = standard. This register can be written only when the I2C interface is disabled, which corresponds to the IC_ENABLE\\[0\\]
-register being set to 0. Writes at other times have no effect. The minimum valid value is 8; hardware prevents values less than this being written, and if attempted results in 8 being set. For designs with APB_DATA_WIDTH = 8 the order of programming is important to ensure the correct operation of the DW_apb_i2c. The lower byte must be programmed first. Then the upper byte is programmed. If the value is less than 8 then the count value gets changed to 8."]
+    #[doc = "Bits 0:15 - This register must be set before any I2C bus transaction can take place to ensure proper I/O timing. This register sets the SCL clock low period count for fast speed. It is used in high-speed mode to send the Master Code and START BYTE or General CALL. For more information, refer to 'IC_CLK Frequency Configuration'.  
+
+ This register goes away and becomes read-only returning 0s if IC_MAX_SPEED_MODE = standard.  
+
+ This register can be written only when the I2C interface is disabled, which corresponds to the IC_ENABLE\\[0\\]
+register being set to 0. Writes at other times have no effect.  
+
+ The minimum valid value is 8; hardware prevents values less than this being written, and if attempted results in 8 being set. For designs with APB_DATA_WIDTH = 8 the order of programming is important to ensure the correct operation of the DW_apb_i2c. The lower byte must be programmed first. Then the upper byte is programmed. If the value is less than 8 then the count value gets changed to 8."]
     #[inline(always)]
     pub fn ic_fs_scl_lcnt(&mut self) -> IC_FS_SCL_LCNT_W {
         IC_FS_SCL_LCNT_W { w: self }
