@@ -36,6 +36,7 @@ impl From<R_RESTART_DET_A> for bool {
  Reset value: 0x0"]
 pub struct R_RESTART_DET_R(crate::FieldReader<bool, R_RESTART_DET_A>);
 impl R_RESTART_DET_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         R_RESTART_DET_R(crate::FieldReader::new(bits))
     }
@@ -88,6 +89,7 @@ impl From<R_GEN_CALL_A> for bool {
  Reset value: 0x0"]
 pub struct R_GEN_CALL_R(crate::FieldReader<bool, R_GEN_CALL_A>);
 impl R_GEN_CALL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         R_GEN_CALL_R(crate::FieldReader::new(bits))
     }
@@ -140,6 +142,7 @@ impl From<R_START_DET_A> for bool {
  Reset value: 0x0"]
 pub struct R_START_DET_R(crate::FieldReader<bool, R_START_DET_A>);
 impl R_START_DET_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         R_START_DET_R(crate::FieldReader::new(bits))
     }
@@ -192,6 +195,7 @@ impl From<R_STOP_DET_A> for bool {
  Reset value: 0x0"]
 pub struct R_STOP_DET_R(crate::FieldReader<bool, R_STOP_DET_A>);
 impl R_STOP_DET_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         R_STOP_DET_R(crate::FieldReader::new(bits))
     }
@@ -244,6 +248,7 @@ impl From<R_ACTIVITY_A> for bool {
  Reset value: 0x0"]
 pub struct R_ACTIVITY_R(crate::FieldReader<bool, R_ACTIVITY_A>);
 impl R_ACTIVITY_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         R_ACTIVITY_R(crate::FieldReader::new(bits))
     }
@@ -296,6 +301,7 @@ impl From<R_RX_DONE_A> for bool {
  Reset value: 0x0"]
 pub struct R_RX_DONE_R(crate::FieldReader<bool, R_RX_DONE_A>);
 impl R_RX_DONE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         R_RX_DONE_R(crate::FieldReader::new(bits))
     }
@@ -348,6 +354,7 @@ impl From<R_TX_ABRT_A> for bool {
  Reset value: 0x0"]
 pub struct R_TX_ABRT_R(crate::FieldReader<bool, R_TX_ABRT_A>);
 impl R_TX_ABRT_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         R_TX_ABRT_R(crate::FieldReader::new(bits))
     }
@@ -400,6 +407,7 @@ impl From<R_RD_REQ_A> for bool {
  Reset value: 0x0"]
 pub struct R_RD_REQ_R(crate::FieldReader<bool, R_RD_REQ_A>);
 impl R_RD_REQ_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         R_RD_REQ_R(crate::FieldReader::new(bits))
     }
@@ -452,6 +460,7 @@ impl From<R_TX_EMPTY_A> for bool {
  Reset value: 0x0"]
 pub struct R_TX_EMPTY_R(crate::FieldReader<bool, R_TX_EMPTY_A>);
 impl R_TX_EMPTY_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         R_TX_EMPTY_R(crate::FieldReader::new(bits))
     }
@@ -504,6 +513,7 @@ impl From<R_TX_OVER_A> for bool {
  Reset value: 0x0"]
 pub struct R_TX_OVER_R(crate::FieldReader<bool, R_TX_OVER_A>);
 impl R_TX_OVER_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         R_TX_OVER_R(crate::FieldReader::new(bits))
     }
@@ -556,6 +566,7 @@ impl From<R_RX_FULL_A> for bool {
  Reset value: 0x0"]
 pub struct R_RX_FULL_R(crate::FieldReader<bool, R_RX_FULL_A>);
 impl R_RX_FULL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         R_RX_FULL_R(crate::FieldReader::new(bits))
     }
@@ -608,6 +619,7 @@ impl From<R_RX_OVER_A> for bool {
  Reset value: 0x0"]
 pub struct R_RX_OVER_R(crate::FieldReader<bool, R_RX_OVER_A>);
 impl R_RX_OVER_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         R_RX_OVER_R(crate::FieldReader::new(bits))
     }
@@ -660,6 +672,7 @@ impl From<R_RX_UNDER_A> for bool {
  Reset value: 0x0"]
 pub struct R_RX_UNDER_R(crate::FieldReader<bool, R_RX_UNDER_A>);
 impl R_RX_UNDER_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         R_RX_UNDER_R(crate::FieldReader::new(bits))
     }
@@ -690,67 +703,93 @@ impl core::ops::Deref for R_RX_UNDER_R {
     }
 }
 impl R {
-    #[doc = "Bit 12 - See IC_RAW_INTR_STAT for a detailed description of R_RESTART_DET bit. Reset value: 0x0"]
+    #[doc = "Bit 12 - See IC_RAW_INTR_STAT for a detailed description of R_RESTART_DET bit.  
+
+ Reset value: 0x0"]
     #[inline(always)]
     pub fn r_restart_det(&self) -> R_RESTART_DET_R {
         R_RESTART_DET_R::new(((self.bits >> 12) & 0x01) != 0)
     }
-    #[doc = "Bit 11 - See IC_RAW_INTR_STAT for a detailed description of R_GEN_CALL bit. Reset value: 0x0"]
+    #[doc = "Bit 11 - See IC_RAW_INTR_STAT for a detailed description of R_GEN_CALL bit.  
+
+ Reset value: 0x0"]
     #[inline(always)]
     pub fn r_gen_call(&self) -> R_GEN_CALL_R {
         R_GEN_CALL_R::new(((self.bits >> 11) & 0x01) != 0)
     }
-    #[doc = "Bit 10 - See IC_RAW_INTR_STAT for a detailed description of R_START_DET bit. Reset value: 0x0"]
+    #[doc = "Bit 10 - See IC_RAW_INTR_STAT for a detailed description of R_START_DET bit.  
+
+ Reset value: 0x0"]
     #[inline(always)]
     pub fn r_start_det(&self) -> R_START_DET_R {
         R_START_DET_R::new(((self.bits >> 10) & 0x01) != 0)
     }
-    #[doc = "Bit 9 - See IC_RAW_INTR_STAT for a detailed description of R_STOP_DET bit. Reset value: 0x0"]
+    #[doc = "Bit 9 - See IC_RAW_INTR_STAT for a detailed description of R_STOP_DET bit.  
+
+ Reset value: 0x0"]
     #[inline(always)]
     pub fn r_stop_det(&self) -> R_STOP_DET_R {
         R_STOP_DET_R::new(((self.bits >> 9) & 0x01) != 0)
     }
-    #[doc = "Bit 8 - See IC_RAW_INTR_STAT for a detailed description of R_ACTIVITY bit. Reset value: 0x0"]
+    #[doc = "Bit 8 - See IC_RAW_INTR_STAT for a detailed description of R_ACTIVITY bit.  
+
+ Reset value: 0x0"]
     #[inline(always)]
     pub fn r_activity(&self) -> R_ACTIVITY_R {
         R_ACTIVITY_R::new(((self.bits >> 8) & 0x01) != 0)
     }
-    #[doc = "Bit 7 - See IC_RAW_INTR_STAT for a detailed description of R_RX_DONE bit. Reset value: 0x0"]
+    #[doc = "Bit 7 - See IC_RAW_INTR_STAT for a detailed description of R_RX_DONE bit.  
+
+ Reset value: 0x0"]
     #[inline(always)]
     pub fn r_rx_done(&self) -> R_RX_DONE_R {
         R_RX_DONE_R::new(((self.bits >> 7) & 0x01) != 0)
     }
-    #[doc = "Bit 6 - See IC_RAW_INTR_STAT for a detailed description of R_TX_ABRT bit. Reset value: 0x0"]
+    #[doc = "Bit 6 - See IC_RAW_INTR_STAT for a detailed description of R_TX_ABRT bit.  
+
+ Reset value: 0x0"]
     #[inline(always)]
     pub fn r_tx_abrt(&self) -> R_TX_ABRT_R {
         R_TX_ABRT_R::new(((self.bits >> 6) & 0x01) != 0)
     }
-    #[doc = "Bit 5 - See IC_RAW_INTR_STAT for a detailed description of R_RD_REQ bit. Reset value: 0x0"]
+    #[doc = "Bit 5 - See IC_RAW_INTR_STAT for a detailed description of R_RD_REQ bit.  
+
+ Reset value: 0x0"]
     #[inline(always)]
     pub fn r_rd_req(&self) -> R_RD_REQ_R {
         R_RD_REQ_R::new(((self.bits >> 5) & 0x01) != 0)
     }
-    #[doc = "Bit 4 - See IC_RAW_INTR_STAT for a detailed description of R_TX_EMPTY bit. Reset value: 0x0"]
+    #[doc = "Bit 4 - See IC_RAW_INTR_STAT for a detailed description of R_TX_EMPTY bit.  
+
+ Reset value: 0x0"]
     #[inline(always)]
     pub fn r_tx_empty(&self) -> R_TX_EMPTY_R {
         R_TX_EMPTY_R::new(((self.bits >> 4) & 0x01) != 0)
     }
-    #[doc = "Bit 3 - See IC_RAW_INTR_STAT for a detailed description of R_TX_OVER bit. Reset value: 0x0"]
+    #[doc = "Bit 3 - See IC_RAW_INTR_STAT for a detailed description of R_TX_OVER bit.  
+
+ Reset value: 0x0"]
     #[inline(always)]
     pub fn r_tx_over(&self) -> R_TX_OVER_R {
         R_TX_OVER_R::new(((self.bits >> 3) & 0x01) != 0)
     }
-    #[doc = "Bit 2 - See IC_RAW_INTR_STAT for a detailed description of R_RX_FULL bit. Reset value: 0x0"]
+    #[doc = "Bit 2 - See IC_RAW_INTR_STAT for a detailed description of R_RX_FULL bit.  
+
+ Reset value: 0x0"]
     #[inline(always)]
     pub fn r_rx_full(&self) -> R_RX_FULL_R {
         R_RX_FULL_R::new(((self.bits >> 2) & 0x01) != 0)
     }
-    #[doc = "Bit 1 - See IC_RAW_INTR_STAT for a detailed description of R_RX_OVER bit. Reset value: 0x0"]
+    #[doc = "Bit 1 - See IC_RAW_INTR_STAT for a detailed description of R_RX_OVER bit.  
+
+ Reset value: 0x0"]
     #[inline(always)]
     pub fn r_rx_over(&self) -> R_RX_OVER_R {
         R_RX_OVER_R::new(((self.bits >> 1) & 0x01) != 0)
     }
-    #[doc = "Bit 0 - See IC_RAW_INTR_STAT for a detailed description of R_RX_UNDER bit. Reset value: 0x0"]
+    #[doc = "Bit 0 - See IC_RAW_INTR_STAT for a detailed description of R_RX_UNDER bit.  
+
+ Reset value: 0x0"]
     #[inline(always)]
     pub fn r_rx_under(&self) -> R_RX_UNDER_R {
         R_RX_UNDER_R::new((self.bits & 0x01) != 0)
