@@ -39,6 +39,7 @@ impl From<crate::W<IC_SDA_HOLD_SPEC>> for W {
  Reset value: IC_DEFAULT_SDA_HOLD\\[23:16\\]."]
 pub struct IC_SDA_RX_HOLD_R(crate::FieldReader<u8, u8>);
 impl IC_SDA_RX_HOLD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         IC_SDA_RX_HOLD_R(crate::FieldReader::new(bits))
     }
@@ -69,6 +70,7 @@ impl<'a> IC_SDA_RX_HOLD_W<'a> {
  Reset value: IC_DEFAULT_SDA_HOLD\\[15:0\\]."]
 pub struct IC_SDA_TX_HOLD_R(crate::FieldReader<u16, u16>);
 impl IC_SDA_TX_HOLD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u16) -> Self {
         IC_SDA_TX_HOLD_R(crate::FieldReader::new(bits))
     }
@@ -95,24 +97,32 @@ impl<'a> IC_SDA_TX_HOLD_W<'a> {
     }
 }
 impl R {
-    #[doc = "Bits 16:23 - Sets the required SDA hold time in units of ic_clk period, when DW_apb_i2c acts as a receiver. Reset value: IC_DEFAULT_SDA_HOLD\\[23:16\\]."]
+    #[doc = "Bits 16:23 - Sets the required SDA hold time in units of ic_clk period, when DW_apb_i2c acts as a receiver.  
+
+ Reset value: IC_DEFAULT_SDA_HOLD\\[23:16\\]."]
     #[inline(always)]
     pub fn ic_sda_rx_hold(&self) -> IC_SDA_RX_HOLD_R {
         IC_SDA_RX_HOLD_R::new(((self.bits >> 16) & 0xff) as u8)
     }
-    #[doc = "Bits 0:15 - Sets the required SDA hold time in units of ic_clk period, when DW_apb_i2c acts as a transmitter. Reset value: IC_DEFAULT_SDA_HOLD\\[15:0\\]."]
+    #[doc = "Bits 0:15 - Sets the required SDA hold time in units of ic_clk period, when DW_apb_i2c acts as a transmitter.  
+
+ Reset value: IC_DEFAULT_SDA_HOLD\\[15:0\\]."]
     #[inline(always)]
     pub fn ic_sda_tx_hold(&self) -> IC_SDA_TX_HOLD_R {
         IC_SDA_TX_HOLD_R::new((self.bits & 0xffff) as u16)
     }
 }
 impl W {
-    #[doc = "Bits 16:23 - Sets the required SDA hold time in units of ic_clk period, when DW_apb_i2c acts as a receiver. Reset value: IC_DEFAULT_SDA_HOLD\\[23:16\\]."]
+    #[doc = "Bits 16:23 - Sets the required SDA hold time in units of ic_clk period, when DW_apb_i2c acts as a receiver.  
+
+ Reset value: IC_DEFAULT_SDA_HOLD\\[23:16\\]."]
     #[inline(always)]
     pub fn ic_sda_rx_hold(&mut self) -> IC_SDA_RX_HOLD_W {
         IC_SDA_RX_HOLD_W { w: self }
     }
-    #[doc = "Bits 0:15 - Sets the required SDA hold time in units of ic_clk period, when DW_apb_i2c acts as a transmitter. Reset value: IC_DEFAULT_SDA_HOLD\\[15:0\\]."]
+    #[doc = "Bits 0:15 - Sets the required SDA hold time in units of ic_clk period, when DW_apb_i2c acts as a transmitter.  
+
+ Reset value: IC_DEFAULT_SDA_HOLD\\[15:0\\]."]
     #[inline(always)]
     pub fn ic_sda_tx_hold(&mut self) -> IC_SDA_TX_HOLD_W {
         IC_SDA_TX_HOLD_W { w: self }
