@@ -32,6 +32,7 @@ impl From<SLV_ACTIVITY_A> for bool {
 #[doc = "Field `SLV_ACTIVITY` reader - Slave FSM Activity Status. When the Slave Finite State Machine (FSM) is not in the IDLE state, this bit is set. - 0: Slave FSM is in IDLE state so the Slave part of DW_apb_i2c is not Active - 1: Slave FSM is not in IDLE state so the Slave part of DW_apb_i2c is Active Reset value: 0x0"]
 pub struct SLV_ACTIVITY_R(crate::FieldReader<bool, SLV_ACTIVITY_A>);
 impl SLV_ACTIVITY_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLV_ACTIVITY_R(crate::FieldReader::new(bits))
     }
@@ -84,6 +85,7 @@ impl From<MST_ACTIVITY_A> for bool {
  Reset value: 0x0"]
 pub struct MST_ACTIVITY_R(crate::FieldReader<bool, MST_ACTIVITY_A>);
 impl MST_ACTIVITY_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         MST_ACTIVITY_R(crate::FieldReader::new(bits))
     }
@@ -132,6 +134,7 @@ impl From<RFF_A> for bool {
 #[doc = "Field `RFF` reader - Receive FIFO Completely Full. When the receive FIFO is completely full, this bit is set. When the receive FIFO contains one or more empty location, this bit is cleared. - 0: Receive FIFO is not full - 1: Receive FIFO is full Reset value: 0x0"]
 pub struct RFF_R(crate::FieldReader<bool, RFF_A>);
 impl RFF_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         RFF_R(crate::FieldReader::new(bits))
     }
@@ -180,6 +183,7 @@ impl From<RFNE_A> for bool {
 #[doc = "Field `RFNE` reader - Receive FIFO Not Empty. This bit is set when the receive FIFO contains one or more entries; it is cleared when the receive FIFO is empty. - 0: Receive FIFO is empty - 1: Receive FIFO is not empty Reset value: 0x0"]
 pub struct RFNE_R(crate::FieldReader<bool, RFNE_A>);
 impl RFNE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         RFNE_R(crate::FieldReader::new(bits))
     }
@@ -228,6 +232,7 @@ impl From<TFE_A> for bool {
 #[doc = "Field `TFE` reader - Transmit FIFO Completely Empty. When the transmit FIFO is completely empty, this bit is set. When it contains one or more valid entries, this bit is cleared. This bit field does not request an interrupt. - 0: Transmit FIFO is not empty - 1: Transmit FIFO is empty Reset value: 0x1"]
 pub struct TFE_R(crate::FieldReader<bool, TFE_A>);
 impl TFE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         TFE_R(crate::FieldReader::new(bits))
     }
@@ -276,6 +281,7 @@ impl From<TFNF_A> for bool {
 #[doc = "Field `TFNF` reader - Transmit FIFO Not Full. Set when the transmit FIFO contains one or more empty locations, and is cleared when the FIFO is full. - 0: Transmit FIFO is full - 1: Transmit FIFO is not full Reset value: 0x1"]
 pub struct TFNF_R(crate::FieldReader<bool, TFNF_A>);
 impl TFNF_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         TFNF_R(crate::FieldReader::new(bits))
     }
@@ -324,6 +330,7 @@ impl From<ACTIVITY_A> for bool {
 #[doc = "Field `ACTIVITY` reader - I2C Activity Status. Reset value: 0x0"]
 pub struct ACTIVITY_R(crate::FieldReader<bool, ACTIVITY_A>);
 impl ACTIVITY_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         ACTIVITY_R(crate::FieldReader::new(bits))
     }
@@ -359,7 +366,9 @@ impl R {
     pub fn slv_activity(&self) -> SLV_ACTIVITY_R {
         SLV_ACTIVITY_R::new(((self.bits >> 6) & 0x01) != 0)
     }
-    #[doc = "Bit 5 - Master FSM Activity Status. When the Master Finite State Machine (FSM) is not in the IDLE state, this bit is set. - 0: Master FSM is in IDLE state so the Master part of DW_apb_i2c is not Active - 1: Master FSM is not in IDLE state so the Master part of DW_apb_i2c is Active Note: IC_STATUS\\[0\\]-that is, ACTIVITY bit-is the OR of SLV_ACTIVITY and MST_ACTIVITY bits. Reset value: 0x0"]
+    #[doc = "Bit 5 - Master FSM Activity Status. When the Master Finite State Machine (FSM) is not in the IDLE state, this bit is set. - 0: Master FSM is in IDLE state so the Master part of DW_apb_i2c is not Active - 1: Master FSM is not in IDLE state so the Master part of DW_apb_i2c is Active Note: IC_STATUS\\[0\\]-that is, ACTIVITY bit-is the OR of SLV_ACTIVITY and MST_ACTIVITY bits.  
+
+ Reset value: 0x0"]
     #[inline(always)]
     pub fn mst_activity(&self) -> MST_ACTIVITY_R {
         MST_ACTIVITY_R::new(((self.bits >> 5) & 0x01) != 0)
