@@ -53,6 +53,7 @@ impl From<SPECIAL_A> for bool {
 #[doc = "Field `SPECIAL` reader - This bit indicates whether software performs a Device-ID or General Call or START BYTE command. - 0: ignore bit 10 GC_OR_START and use IC_TAR normally - 1: perform special I2C command as specified in Device_ID or GC_OR_START bit Reset value: 0x0"]
 pub struct SPECIAL_R(crate::FieldReader<bool, SPECIAL_A>);
 impl SPECIAL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPECIAL_R(crate::FieldReader::new(bits))
     }
@@ -138,6 +139,7 @@ impl From<GC_OR_START_A> for bool {
 #[doc = "Field `GC_OR_START` reader - If bit 11 (SPECIAL) is set to 1 and bit 13(Device-ID) is set to 0, then this bit indicates whether a General Call or START byte command is to be performed by the DW_apb_i2c. - 0: General Call Address - after issuing a General Call, only writes may be performed. Attempting to issue a read command results in setting bit 6 (TX_ABRT) of the IC_RAW_INTR_STAT register. The DW_apb_i2c remains in General Call mode until the SPECIAL bit value (bit 11) is cleared. - 1: START BYTE Reset value: 0x0"]
 pub struct GC_OR_START_R(crate::FieldReader<bool, GC_OR_START_A>);
 impl GC_OR_START_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         GC_OR_START_R(crate::FieldReader::new(bits))
     }
@@ -209,6 +211,7 @@ impl<'a> GC_OR_START_W<'a> {
  If the IC_TAR and IC_SAR are the same, loopback exists but the FIFOs are shared between master and slave, so full loopback is not feasible. Only one direction loopback mode is supported (simplex), not duplex. A master cannot transmit to itself; it can transmit to only a slave."]
 pub struct IC_TAR_R(crate::FieldReader<u16, u16>);
 impl IC_TAR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u16) -> Self {
         IC_TAR_R(crate::FieldReader::new(bits))
     }
@@ -245,7 +248,9 @@ impl R {
     pub fn gc_or_start(&self) -> GC_OR_START_R {
         GC_OR_START_R::new(((self.bits >> 10) & 0x01) != 0)
     }
-    #[doc = "Bits 0:9 - This is the target address for any master transaction. When transmitting a General Call, these bits are ignored. To generate a START BYTE, the CPU needs to write only once into these bits. If the IC_TAR and IC_SAR are the same, loopback exists but the FIFOs are shared between master and slave, so full loopback is not feasible. Only one direction loopback mode is supported (simplex), not duplex. A master cannot transmit to itself; it can transmit to only a slave."]
+    #[doc = "Bits 0:9 - This is the target address for any master transaction. When transmitting a General Call, these bits are ignored. To generate a START BYTE, the CPU needs to write only once into these bits.  
+
+ If the IC_TAR and IC_SAR are the same, loopback exists but the FIFOs are shared between master and slave, so full loopback is not feasible. Only one direction loopback mode is supported (simplex), not duplex. A master cannot transmit to itself; it can transmit to only a slave."]
     #[inline(always)]
     pub fn ic_tar(&self) -> IC_TAR_R {
         IC_TAR_R::new((self.bits & 0x03ff) as u16)
@@ -262,7 +267,9 @@ impl W {
     pub fn gc_or_start(&mut self) -> GC_OR_START_W {
         GC_OR_START_W { w: self }
     }
-    #[doc = "Bits 0:9 - This is the target address for any master transaction. When transmitting a General Call, these bits are ignored. To generate a START BYTE, the CPU needs to write only once into these bits. If the IC_TAR and IC_SAR are the same, loopback exists but the FIFOs are shared between master and slave, so full loopback is not feasible. Only one direction loopback mode is supported (simplex), not duplex. A master cannot transmit to itself; it can transmit to only a slave."]
+    #[doc = "Bits 0:9 - This is the target address for any master transaction. When transmitting a General Call, these bits are ignored. To generate a START BYTE, the CPU needs to write only once into these bits.  
+
+ If the IC_TAR and IC_SAR are the same, loopback exists but the FIFOs are shared between master and slave, so full loopback is not feasible. Only one direction loopback mode is supported (simplex), not duplex. A master cannot transmit to itself; it can transmit to only a slave."]
     #[inline(always)]
     pub fn ic_tar(&mut self) -> IC_TAR_W {
         IC_TAR_W { w: self }
