@@ -16,6 +16,7 @@ impl From<crate::R<CPUID_SPEC>> for R {
 #[doc = "Field `IMPLEMENTER` reader - Implementor code: 0x41 = ARM"]
 pub struct IMPLEMENTER_R(crate::FieldReader<u8, u8>);
 impl IMPLEMENTER_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         IMPLEMENTER_R(crate::FieldReader::new(bits))
     }
@@ -31,6 +32,7 @@ impl core::ops::Deref for IMPLEMENTER_R {
  0x0 = Revision 0."]
 pub struct VARIANT_R(crate::FieldReader<u8, u8>);
 impl VARIANT_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         VARIANT_R(crate::FieldReader::new(bits))
     }
@@ -46,6 +48,7 @@ impl core::ops::Deref for VARIANT_R {
  0xC = ARMv6-M architecture."]
 pub struct ARCHITECTURE_R(crate::FieldReader<u8, u8>);
 impl ARCHITECTURE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         ARCHITECTURE_R(crate::FieldReader::new(bits))
     }
@@ -60,6 +63,7 @@ impl core::ops::Deref for ARCHITECTURE_R {
 #[doc = "Field `PARTNO` reader - Number of processor within family: 0xC60 = Cortex-M0+"]
 pub struct PARTNO_R(crate::FieldReader<u16, u16>);
 impl PARTNO_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u16) -> Self {
         PARTNO_R(crate::FieldReader::new(bits))
     }
@@ -75,6 +79,7 @@ impl core::ops::Deref for PARTNO_R {
  0x1 = Patch 1."]
 pub struct REVISION_R(crate::FieldReader<u8, u8>);
 impl REVISION_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         REVISION_R(crate::FieldReader::new(bits))
     }
@@ -92,12 +97,14 @@ impl R {
     pub fn implementer(&self) -> IMPLEMENTER_R {
         IMPLEMENTER_R::new(((self.bits >> 24) & 0xff) as u8)
     }
-    #[doc = "Bits 20:23 - Major revision number n in the rnpm revision status: 0x0 = Revision 0."]
+    #[doc = "Bits 20:23 - Major revision number n in the rnpm revision status:  
+ 0x0 = Revision 0."]
     #[inline(always)]
     pub fn variant(&self) -> VARIANT_R {
         VARIANT_R::new(((self.bits >> 20) & 0x0f) as u8)
     }
-    #[doc = "Bits 16:19 - Constant that defines the architecture of the processor: 0xC = ARMv6-M architecture."]
+    #[doc = "Bits 16:19 - Constant that defines the architecture of the processor:  
+ 0xC = ARMv6-M architecture."]
     #[inline(always)]
     pub fn architecture(&self) -> ARCHITECTURE_R {
         ARCHITECTURE_R::new(((self.bits >> 16) & 0x0f) as u8)
@@ -107,7 +114,8 @@ impl R {
     pub fn partno(&self) -> PARTNO_R {
         PARTNO_R::new(((self.bits >> 4) & 0x0fff) as u16)
     }
-    #[doc = "Bits 0:3 - Minor revision number m in the rnpm revision status: 0x1 = Patch 1."]
+    #[doc = "Bits 0:3 - Minor revision number m in the rnpm revision status:  
+ 0x1 = Patch 1."]
     #[inline(always)]
     pub fn revision(&self) -> REVISION_R {
         REVISION_R::new((self.bits & 0x0f) as u8)
