@@ -48,6 +48,7 @@ impl From<crate::W<ICSR_SPEC>> for W {
  NMI signal is reasserted while the processor is executing that handler."]
 pub struct NMIPENDSET_R(crate::FieldReader<bool, bool>);
 impl NMIPENDSET_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         NMIPENDSET_R(crate::FieldReader::new(bits))
     }
@@ -102,6 +103,7 @@ impl<'a> NMIPENDSET_W<'a> {
  Writing 1 to this bit is the only way to set the PendSV exception state to pending."]
 pub struct PENDSVSET_R(crate::FieldReader<bool, bool>);
 impl PENDSVSET_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         PENDSVSET_R(crate::FieldReader::new(bits))
     }
@@ -148,6 +150,7 @@ impl<'a> PENDSVSET_W<'a> {
  1 = Removes the pending state from the PendSV exception."]
 pub struct PENDSVCLR_R(crate::FieldReader<bool, bool>);
 impl PENDSVCLR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         PENDSVCLR_R(crate::FieldReader::new(bits))
     }
@@ -193,6 +196,7 @@ impl<'a> PENDSVCLR_W<'a> {
  1 = SysTick exception is pending."]
 pub struct PENDSTSET_R(crate::FieldReader<bool, bool>);
 impl PENDSTSET_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         PENDSTSET_R(crate::FieldReader::new(bits))
     }
@@ -239,6 +243,7 @@ impl<'a> PENDSTSET_W<'a> {
  This bit is WO. On a register read its value is Unknown."]
 pub struct PENDSTCLR_R(crate::FieldReader<bool, bool>);
 impl PENDSTCLR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         PENDSTCLR_R(crate::FieldReader::new(bits))
     }
@@ -279,6 +284,7 @@ impl<'a> PENDSTCLR_W<'a> {
 #[doc = "Field `ISRPREEMPT` reader - The system can only access this bit when the core is halted. It indicates that a pending interrupt is to be taken in the next running cycle. If C_MASKINTS is clear in the Debug Halting Control and Status Register, the interrupt is serviced."]
 pub struct ISRPREEMPT_R(crate::FieldReader<bool, bool>);
 impl ISRPREEMPT_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         ISRPREEMPT_R(crate::FieldReader::new(bits))
     }
@@ -293,6 +299,7 @@ impl core::ops::Deref for ISRPREEMPT_R {
 #[doc = "Field `ISRPENDING` reader - External interrupt pending flag"]
 pub struct ISRPENDING_R(crate::FieldReader<bool, bool>);
 impl ISRPENDING_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         ISRPENDING_R(crate::FieldReader::new(bits))
     }
@@ -307,6 +314,7 @@ impl core::ops::Deref for ISRPENDING_R {
 #[doc = "Field `VECTPENDING` reader - Indicates the exception number for the highest priority pending exception: 0 = no pending exceptions. Non zero = The pending state includes the effect of memory-mapped enable and mask registers. It does not include the PRIMASK special-purpose register qualifier."]
 pub struct VECTPENDING_R(crate::FieldReader<u16, u16>);
 impl VECTPENDING_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u16) -> Self {
         VECTPENDING_R(crate::FieldReader::new(bits))
     }
@@ -321,6 +329,7 @@ impl core::ops::Deref for VECTPENDING_R {
 #[doc = "Field `VECTACTIVE` reader - Active exception number field. Reset clears the VECTACTIVE field."]
 pub struct VECTACTIVE_R(crate::FieldReader<u16, u16>);
 impl VECTACTIVE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u16) -> Self {
         VECTACTIVE_R(crate::FieldReader::new(bits))
     }
@@ -333,27 +342,58 @@ impl core::ops::Deref for VECTACTIVE_R {
     }
 }
 impl R {
-    #[doc = "Bit 31 - Setting this bit will activate an NMI. Since NMI is the highest priority exception, it will activate as soon as it is registered. NMI set-pending bit. Write: 0 = No effect. 1 = Changes NMI exception state to pending. Read: 0 = NMI exception is not pending. 1 = NMI exception is pending. Because NMI is the highest-priority exception, normally the processor enters the NMI exception handler as soon as it detects a write of 1 to this bit. Entering the handler then clears this bit to 0. This means a read of this bit by the NMI exception handler returns 1 only if the NMI signal is reasserted while the processor is executing that handler."]
+    #[doc = "Bit 31 - Setting this bit will activate an NMI. Since NMI is the highest priority exception, it will activate as soon as it is registered.  
+ NMI set-pending bit.  
+ Write:  
+ 0 = No effect.  
+ 1 = Changes NMI exception state to pending.  
+ Read:  
+ 0 = NMI exception is not pending.  
+ 1 = NMI exception is pending.  
+ Because NMI is the highest-priority exception, normally the processor enters the NMI  
+ exception handler as soon as it detects a write of 1 to this bit. Entering the handler then clears  
+ this bit to 0. This means a read of this bit by the NMI exception handler returns 1 only if the  
+ NMI signal is reasserted while the processor is executing that handler."]
     #[inline(always)]
     pub fn nmipendset(&self) -> NMIPENDSET_R {
         NMIPENDSET_R::new(((self.bits >> 31) & 0x01) != 0)
     }
-    #[doc = "Bit 28 - PendSV set-pending bit. Write: 0 = No effect. 1 = Changes PendSV exception state to pending. Read: 0 = PendSV exception is not pending. 1 = PendSV exception is pending. Writing 1 to this bit is the only way to set the PendSV exception state to pending."]
+    #[doc = "Bit 28 - PendSV set-pending bit.  
+ Write:  
+ 0 = No effect.  
+ 1 = Changes PendSV exception state to pending.  
+ Read:  
+ 0 = PendSV exception is not pending.  
+ 1 = PendSV exception is pending.  
+ Writing 1 to this bit is the only way to set the PendSV exception state to pending."]
     #[inline(always)]
     pub fn pendsvset(&self) -> PENDSVSET_R {
         PENDSVSET_R::new(((self.bits >> 28) & 0x01) != 0)
     }
-    #[doc = "Bit 27 - PendSV clear-pending bit. Write: 0 = No effect. 1 = Removes the pending state from the PendSV exception."]
+    #[doc = "Bit 27 - PendSV clear-pending bit.  
+ Write:  
+ 0 = No effect.  
+ 1 = Removes the pending state from the PendSV exception."]
     #[inline(always)]
     pub fn pendsvclr(&self) -> PENDSVCLR_R {
         PENDSVCLR_R::new(((self.bits >> 27) & 0x01) != 0)
     }
-    #[doc = "Bit 26 - SysTick exception set-pending bit. Write: 0 = No effect. 1 = Changes SysTick exception state to pending. Read: 0 = SysTick exception is not pending. 1 = SysTick exception is pending."]
+    #[doc = "Bit 26 - SysTick exception set-pending bit.  
+ Write:  
+ 0 = No effect.  
+ 1 = Changes SysTick exception state to pending.  
+ Read:  
+ 0 = SysTick exception is not pending.  
+ 1 = SysTick exception is pending."]
     #[inline(always)]
     pub fn pendstset(&self) -> PENDSTSET_R {
         PENDSTSET_R::new(((self.bits >> 26) & 0x01) != 0)
     }
-    #[doc = "Bit 25 - SysTick exception clear-pending bit. Write: 0 = No effect. 1 = Removes the pending state from the SysTick exception. This bit is WO. On a register read its value is Unknown."]
+    #[doc = "Bit 25 - SysTick exception clear-pending bit.  
+ Write:  
+ 0 = No effect.  
+ 1 = Removes the pending state from the SysTick exception.  
+ This bit is WO. On a register read its value is Unknown."]
     #[inline(always)]
     pub fn pendstclr(&self) -> PENDSTCLR_R {
         PENDSTCLR_R::new(((self.bits >> 25) & 0x01) != 0)
@@ -380,27 +420,58 @@ impl R {
     }
 }
 impl W {
-    #[doc = "Bit 31 - Setting this bit will activate an NMI. Since NMI is the highest priority exception, it will activate as soon as it is registered. NMI set-pending bit. Write: 0 = No effect. 1 = Changes NMI exception state to pending. Read: 0 = NMI exception is not pending. 1 = NMI exception is pending. Because NMI is the highest-priority exception, normally the processor enters the NMI exception handler as soon as it detects a write of 1 to this bit. Entering the handler then clears this bit to 0. This means a read of this bit by the NMI exception handler returns 1 only if the NMI signal is reasserted while the processor is executing that handler."]
+    #[doc = "Bit 31 - Setting this bit will activate an NMI. Since NMI is the highest priority exception, it will activate as soon as it is registered.  
+ NMI set-pending bit.  
+ Write:  
+ 0 = No effect.  
+ 1 = Changes NMI exception state to pending.  
+ Read:  
+ 0 = NMI exception is not pending.  
+ 1 = NMI exception is pending.  
+ Because NMI is the highest-priority exception, normally the processor enters the NMI  
+ exception handler as soon as it detects a write of 1 to this bit. Entering the handler then clears  
+ this bit to 0. This means a read of this bit by the NMI exception handler returns 1 only if the  
+ NMI signal is reasserted while the processor is executing that handler."]
     #[inline(always)]
     pub fn nmipendset(&mut self) -> NMIPENDSET_W {
         NMIPENDSET_W { w: self }
     }
-    #[doc = "Bit 28 - PendSV set-pending bit. Write: 0 = No effect. 1 = Changes PendSV exception state to pending. Read: 0 = PendSV exception is not pending. 1 = PendSV exception is pending. Writing 1 to this bit is the only way to set the PendSV exception state to pending."]
+    #[doc = "Bit 28 - PendSV set-pending bit.  
+ Write:  
+ 0 = No effect.  
+ 1 = Changes PendSV exception state to pending.  
+ Read:  
+ 0 = PendSV exception is not pending.  
+ 1 = PendSV exception is pending.  
+ Writing 1 to this bit is the only way to set the PendSV exception state to pending."]
     #[inline(always)]
     pub fn pendsvset(&mut self) -> PENDSVSET_W {
         PENDSVSET_W { w: self }
     }
-    #[doc = "Bit 27 - PendSV clear-pending bit. Write: 0 = No effect. 1 = Removes the pending state from the PendSV exception."]
+    #[doc = "Bit 27 - PendSV clear-pending bit.  
+ Write:  
+ 0 = No effect.  
+ 1 = Removes the pending state from the PendSV exception."]
     #[inline(always)]
     pub fn pendsvclr(&mut self) -> PENDSVCLR_W {
         PENDSVCLR_W { w: self }
     }
-    #[doc = "Bit 26 - SysTick exception set-pending bit. Write: 0 = No effect. 1 = Changes SysTick exception state to pending. Read: 0 = SysTick exception is not pending. 1 = SysTick exception is pending."]
+    #[doc = "Bit 26 - SysTick exception set-pending bit.  
+ Write:  
+ 0 = No effect.  
+ 1 = Changes SysTick exception state to pending.  
+ Read:  
+ 0 = SysTick exception is not pending.  
+ 1 = SysTick exception is pending."]
     #[inline(always)]
     pub fn pendstset(&mut self) -> PENDSTSET_W {
         PENDSTSET_W { w: self }
     }
-    #[doc = "Bit 25 - SysTick exception clear-pending bit. Write: 0 = No effect. 1 = Removes the pending state from the SysTick exception. This bit is WO. On a register read its value is Unknown."]
+    #[doc = "Bit 25 - SysTick exception clear-pending bit.  
+ Write:  
+ 0 = No effect.  
+ 1 = Removes the pending state from the SysTick exception.  
+ This bit is WO. On a register read its value is Unknown."]
     #[inline(always)]
     pub fn pendstclr(&mut self) -> PENDSTCLR_W {
         PENDSTCLR_W { w: self }
