@@ -41,6 +41,7 @@ impl From<crate::W<MPU_CTRL_SPEC>> for W {
  When enabled, the background region acts as if it is region number -1. Any region that is defined and enabled has priority over this default map."]
 pub struct PRIVDEFENA_R(crate::FieldReader<bool, bool>);
 impl PRIVDEFENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         PRIVDEFENA_R(crate::FieldReader::new(bits))
     }
@@ -84,6 +85,7 @@ impl<'a> PRIVDEFENA_W<'a> {
  1 = the MPU is enabled during HardFault and NMI handlers."]
 pub struct HFNMIENA_R(crate::FieldReader<bool, bool>);
 impl HFNMIENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         HFNMIENA_R(crate::FieldReader::new(bits))
     }
@@ -125,6 +127,7 @@ impl<'a> HFNMIENA_W<'a> {
  1 = MPU enabled."]
 pub struct ENABLE_R(crate::FieldReader<bool, bool>);
 impl ENABLE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         ENABLE_R(crate::FieldReader::new(bits))
     }
@@ -161,34 +164,52 @@ impl<'a> ENABLE_W<'a> {
     }
 }
 impl R {
-    #[doc = "Bit 2 - Controls whether the default memory map is enabled as a background region for privileged accesses. This bit is ignored when ENABLE is clear. 0 = If the MPU is enabled, disables use of the default memory map. Any memory access to a location not covered by any enabled region causes a fault. 1 = If the MPU is enabled, enables use of the default memory map as a background region for privileged software accesses. When enabled, the background region acts as if it is region number -1. Any region that is defined and enabled has priority over this default map."]
+    #[doc = "Bit 2 - Controls whether the default memory map is enabled as a background region for privileged accesses. This bit is ignored when ENABLE is clear.  
+ 0 = If the MPU is enabled, disables use of the default memory map. Any memory access to a location not  
+ covered by any enabled region causes a fault.  
+ 1 = If the MPU is enabled, enables use of the default memory map as a background region for privileged software accesses.  
+ When enabled, the background region acts as if it is region number -1. Any region that is defined and enabled has priority over this default map."]
     #[inline(always)]
     pub fn privdefena(&self) -> PRIVDEFENA_R {
         PRIVDEFENA_R::new(((self.bits >> 2) & 0x01) != 0)
     }
-    #[doc = "Bit 1 - Controls the use of the MPU for HardFaults and NMIs. Setting this bit when ENABLE is clear results in UNPREDICTABLE behaviour. When the MPU is enabled: 0 = MPU is disabled during HardFault and NMI handlers, regardless of the value of the ENABLE bit. 1 = the MPU is enabled during HardFault and NMI handlers."]
+    #[doc = "Bit 1 - Controls the use of the MPU for HardFaults and NMIs. Setting this bit when ENABLE is clear results in UNPREDICTABLE behaviour.  
+ When the MPU is enabled:  
+ 0 = MPU is disabled during HardFault and NMI handlers, regardless of the value of the ENABLE bit.  
+ 1 = the MPU is enabled during HardFault and NMI handlers."]
     #[inline(always)]
     pub fn hfnmiena(&self) -> HFNMIENA_R {
         HFNMIENA_R::new(((self.bits >> 1) & 0x01) != 0)
     }
-    #[doc = "Bit 0 - Enables the MPU. If the MPU is disabled, privileged and unprivileged accesses use the default memory map. 0 = MPU disabled. 1 = MPU enabled."]
+    #[doc = "Bit 0 - Enables the MPU. If the MPU is disabled, privileged and unprivileged accesses use the default memory map.  
+ 0 = MPU disabled.  
+ 1 = MPU enabled."]
     #[inline(always)]
     pub fn enable(&self) -> ENABLE_R {
         ENABLE_R::new((self.bits & 0x01) != 0)
     }
 }
 impl W {
-    #[doc = "Bit 2 - Controls whether the default memory map is enabled as a background region for privileged accesses. This bit is ignored when ENABLE is clear. 0 = If the MPU is enabled, disables use of the default memory map. Any memory access to a location not covered by any enabled region causes a fault. 1 = If the MPU is enabled, enables use of the default memory map as a background region for privileged software accesses. When enabled, the background region acts as if it is region number -1. Any region that is defined and enabled has priority over this default map."]
+    #[doc = "Bit 2 - Controls whether the default memory map is enabled as a background region for privileged accesses. This bit is ignored when ENABLE is clear.  
+ 0 = If the MPU is enabled, disables use of the default memory map. Any memory access to a location not  
+ covered by any enabled region causes a fault.  
+ 1 = If the MPU is enabled, enables use of the default memory map as a background region for privileged software accesses.  
+ When enabled, the background region acts as if it is region number -1. Any region that is defined and enabled has priority over this default map."]
     #[inline(always)]
     pub fn privdefena(&mut self) -> PRIVDEFENA_W {
         PRIVDEFENA_W { w: self }
     }
-    #[doc = "Bit 1 - Controls the use of the MPU for HardFaults and NMIs. Setting this bit when ENABLE is clear results in UNPREDICTABLE behaviour. When the MPU is enabled: 0 = MPU is disabled during HardFault and NMI handlers, regardless of the value of the ENABLE bit. 1 = the MPU is enabled during HardFault and NMI handlers."]
+    #[doc = "Bit 1 - Controls the use of the MPU for HardFaults and NMIs. Setting this bit when ENABLE is clear results in UNPREDICTABLE behaviour.  
+ When the MPU is enabled:  
+ 0 = MPU is disabled during HardFault and NMI handlers, regardless of the value of the ENABLE bit.  
+ 1 = the MPU is enabled during HardFault and NMI handlers."]
     #[inline(always)]
     pub fn hfnmiena(&mut self) -> HFNMIENA_W {
         HFNMIENA_W { w: self }
     }
-    #[doc = "Bit 0 - Enables the MPU. If the MPU is disabled, privileged and unprivileged accesses use the default memory map. 0 = MPU disabled. 1 = MPU enabled."]
+    #[doc = "Bit 0 - Enables the MPU. If the MPU is disabled, privileged and unprivileged accesses use the default memory map.  
+ 0 = MPU disabled.  
+ 1 = MPU enabled."]
     #[inline(always)]
     pub fn enable(&mut self) -> ENABLE_W {
         ENABLE_W { w: self }
