@@ -41,6 +41,7 @@ impl From<crate::W<GPIO_HI_OE_SPEC>> for W {
  and the write from core 1 was then applied to that intermediate result."]
 pub struct GPIO_HI_OE_R(crate::FieldReader<u8, u8>);
 impl GPIO_HI_OE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         GPIO_HI_OE_R(crate::FieldReader::new(bits))
     }
@@ -69,14 +70,22 @@ impl<'a> GPIO_HI_OE_W<'a> {
     }
 }
 impl R {
-    #[doc = "Bits 0:5 - Set output enable (1/0 -> output/input) for QSPI IO0...5. Reading back gives the last value written. If core 0 and core 1 both write to GPIO_HI_OE simultaneously (or to a SET/CLR/XOR alias), the result is as though the write from core 0 took place first, and the write from core 1 was then applied to that intermediate result."]
+    #[doc = "Bits 0:5 - Set output enable (1/0 -> output/input) for QSPI IO0...5.  
+ Reading back gives the last value written.  
+ If core 0 and core 1 both write to GPIO_HI_OE simultaneously (or to a SET/CLR/XOR alias),  
+ the result is as though the write from core 0 took place first,  
+ and the write from core 1 was then applied to that intermediate result."]
     #[inline(always)]
     pub fn gpio_hi_oe(&self) -> GPIO_HI_OE_R {
         GPIO_HI_OE_R::new((self.bits & 0x3f) as u8)
     }
 }
 impl W {
-    #[doc = "Bits 0:5 - Set output enable (1/0 -> output/input) for QSPI IO0...5. Reading back gives the last value written. If core 0 and core 1 both write to GPIO_HI_OE simultaneously (or to a SET/CLR/XOR alias), the result is as though the write from core 0 took place first, and the write from core 1 was then applied to that intermediate result."]
+    #[doc = "Bits 0:5 - Set output enable (1/0 -> output/input) for QSPI IO0...5.  
+ Reading back gives the last value written.  
+ If core 0 and core 1 both write to GPIO_HI_OE simultaneously (or to a SET/CLR/XOR alias),  
+ the result is as though the write from core 0 took place first,  
+ and the write from core 1 was then applied to that intermediate result."]
     #[inline(always)]
     pub fn gpio_hi_oe(&mut self) -> GPIO_HI_OE_W {
         GPIO_HI_OE_W { w: self }
