@@ -41,6 +41,7 @@ impl From<crate::W<GPIO_HI_OUT_SPEC>> for W {
  and the write from core 1 was then applied to that intermediate result."]
 pub struct GPIO_HI_OUT_R(crate::FieldReader<u8, u8>);
 impl GPIO_HI_OUT_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         GPIO_HI_OUT_R(crate::FieldReader::new(bits))
     }
@@ -69,14 +70,22 @@ impl<'a> GPIO_HI_OUT_W<'a> {
     }
 }
 impl R {
-    #[doc = "Bits 0:5 - Set output level (1/0 -> high/low) for QSPI IO0...5. Reading back gives the last value written, NOT the input value from the pins. If core 0 and core 1 both write to GPIO_HI_OUT simultaneously (or to a SET/CLR/XOR alias), the result is as though the write from core 0 took place first, and the write from core 1 was then applied to that intermediate result."]
+    #[doc = "Bits 0:5 - Set output level (1/0 -> high/low) for QSPI IO0...5.  
+ Reading back gives the last value written, NOT the input value from the pins.  
+ If core 0 and core 1 both write to GPIO_HI_OUT simultaneously (or to a SET/CLR/XOR alias),  
+ the result is as though the write from core 0 took place first,  
+ and the write from core 1 was then applied to that intermediate result."]
     #[inline(always)]
     pub fn gpio_hi_out(&self) -> GPIO_HI_OUT_R {
         GPIO_HI_OUT_R::new((self.bits & 0x3f) as u8)
     }
 }
 impl W {
-    #[doc = "Bits 0:5 - Set output level (1/0 -> high/low) for QSPI IO0...5. Reading back gives the last value written, NOT the input value from the pins. If core 0 and core 1 both write to GPIO_HI_OUT simultaneously (or to a SET/CLR/XOR alias), the result is as though the write from core 0 took place first, and the write from core 1 was then applied to that intermediate result."]
+    #[doc = "Bits 0:5 - Set output level (1/0 -> high/low) for QSPI IO0...5.  
+ Reading back gives the last value written, NOT the input value from the pins.  
+ If core 0 and core 1 both write to GPIO_HI_OUT simultaneously (or to a SET/CLR/XOR alias),  
+ the result is as though the write from core 0 took place first,  
+ and the write from core 1 was then applied to that intermediate result."]
     #[inline(always)]
     pub fn gpio_hi_out(&mut self) -> GPIO_HI_OUT_W {
         GPIO_HI_OUT_W { w: self }
