@@ -41,6 +41,7 @@ impl From<crate::W<GPIO_OE_SPEC>> for W {
  and the write from core 1 was then applied to that intermediate result."]
 pub struct GPIO_OE_R(crate::FieldReader<u32, u32>);
 impl GPIO_OE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u32) -> Self {
         GPIO_OE_R(crate::FieldReader::new(bits))
     }
@@ -69,14 +70,22 @@ impl<'a> GPIO_OE_W<'a> {
     }
 }
 impl R {
-    #[doc = "Bits 0:29 - Set output enable (1/0 -> output/input) for GPIO0...29. Reading back gives the last value written. If core 0 and core 1 both write to GPIO_OE simultaneously (or to a SET/CLR/XOR alias), the result is as though the write from core 0 took place first, and the write from core 1 was then applied to that intermediate result."]
+    #[doc = "Bits 0:29 - Set output enable (1/0 -> output/input) for GPIO0...29.  
+ Reading back gives the last value written.  
+ If core 0 and core 1 both write to GPIO_OE simultaneously (or to a SET/CLR/XOR alias),  
+ the result is as though the write from core 0 took place first,  
+ and the write from core 1 was then applied to that intermediate result."]
     #[inline(always)]
     pub fn gpio_oe(&self) -> GPIO_OE_R {
         GPIO_OE_R::new((self.bits & 0x3fff_ffff) as u32)
     }
 }
 impl W {
-    #[doc = "Bits 0:29 - Set output enable (1/0 -> output/input) for GPIO0...29. Reading back gives the last value written. If core 0 and core 1 both write to GPIO_OE simultaneously (or to a SET/CLR/XOR alias), the result is as though the write from core 0 took place first, and the write from core 1 was then applied to that intermediate result."]
+    #[doc = "Bits 0:29 - Set output enable (1/0 -> output/input) for GPIO0...29.  
+ Reading back gives the last value written.  
+ If core 0 and core 1 both write to GPIO_OE simultaneously (or to a SET/CLR/XOR alias),  
+ the result is as though the write from core 0 took place first,  
+ and the write from core 1 was then applied to that intermediate result."]
     #[inline(always)]
     pub fn gpio_oe(&mut self) -> GPIO_OE_W {
         GPIO_OE_W { w: self }
