@@ -41,6 +41,7 @@ impl From<crate::W<GPIO_OUT_SPEC>> for W {
  and the write from core 1 was then applied to that intermediate result."]
 pub struct GPIO_OUT_R(crate::FieldReader<u32, u32>);
 impl GPIO_OUT_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u32) -> Self {
         GPIO_OUT_R(crate::FieldReader::new(bits))
     }
@@ -69,14 +70,22 @@ impl<'a> GPIO_OUT_W<'a> {
     }
 }
 impl R {
-    #[doc = "Bits 0:29 - Set output level (1/0 -> high/low) for GPIO0...29. Reading back gives the last value written, NOT the input value from the pins. If core 0 and core 1 both write to GPIO_OUT simultaneously (or to a SET/CLR/XOR alias), the result is as though the write from core 0 took place first, and the write from core 1 was then applied to that intermediate result."]
+    #[doc = "Bits 0:29 - Set output level (1/0 -> high/low) for GPIO0...29.  
+ Reading back gives the last value written, NOT the input value from the pins.  
+ If core 0 and core 1 both write to GPIO_OUT simultaneously (or to a SET/CLR/XOR alias),  
+ the result is as though the write from core 0 took place first,  
+ and the write from core 1 was then applied to that intermediate result."]
     #[inline(always)]
     pub fn gpio_out(&self) -> GPIO_OUT_R {
         GPIO_OUT_R::new((self.bits & 0x3fff_ffff) as u32)
     }
 }
 impl W {
-    #[doc = "Bits 0:29 - Set output level (1/0 -> high/low) for GPIO0...29. Reading back gives the last value written, NOT the input value from the pins. If core 0 and core 1 both write to GPIO_OUT simultaneously (or to a SET/CLR/XOR alias), the result is as though the write from core 0 took place first, and the write from core 1 was then applied to that intermediate result."]
+    #[doc = "Bits 0:29 - Set output level (1/0 -> high/low) for GPIO0...29.  
+ Reading back gives the last value written, NOT the input value from the pins.  
+ If core 0 and core 1 both write to GPIO_OUT simultaneously (or to a SET/CLR/XOR alias),  
+ the result is as though the write from core 0 took place first,  
+ and the write from core 1 was then applied to that intermediate result."]
     #[inline(always)]
     pub fn gpio_out(&mut self) -> GPIO_OUT_W {
         GPIO_OUT_W { w: self }
