@@ -37,6 +37,7 @@ impl From<crate::W<INTERP1_CTRL_LANE0_SPEC>> for W {
 #[doc = "Field `OVERF` reader - Set if either OVERF0 or OVERF1 is set."]
 pub struct OVERF_R(crate::FieldReader<bool, bool>);
 impl OVERF_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         OVERF_R(crate::FieldReader::new(bits))
     }
@@ -51,6 +52,7 @@ impl core::ops::Deref for OVERF_R {
 #[doc = "Field `OVERF1` reader - Indicates if any masked-off MSBs in ACCUM1 are set."]
 pub struct OVERF1_R(crate::FieldReader<bool, bool>);
 impl OVERF1_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         OVERF1_R(crate::FieldReader::new(bits))
     }
@@ -65,6 +67,7 @@ impl core::ops::Deref for OVERF1_R {
 #[doc = "Field `OVERF0` reader - Indicates if any masked-off MSBs in ACCUM0 are set."]
 pub struct OVERF0_R(crate::FieldReader<bool, bool>);
 impl OVERF0_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         OVERF0_R(crate::FieldReader::new(bits))
     }
@@ -82,6 +85,7 @@ impl core::ops::Deref for OVERF0_R {
  - Signedness of these comparisons is determined by LANE0_CTRL_SIGNED"]
 pub struct CLAMP_R(crate::FieldReader<bool, bool>);
 impl CLAMP_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CLAMP_R(crate::FieldReader::new(bits))
     }
@@ -123,6 +127,7 @@ impl<'a> CLAMP_W<'a> {
  of pointers into flash or SRAM."]
 pub struct FORCE_MSB_R(crate::FieldReader<u8, u8>);
 impl FORCE_MSB_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         FORCE_MSB_R(crate::FieldReader::new(bits))
     }
@@ -151,6 +156,7 @@ impl<'a> FORCE_MSB_W<'a> {
 #[doc = "Field `ADD_RAW` reader - If 1, mask + shift is bypassed for LANE0 result. This does not affect FULL result."]
 pub struct ADD_RAW_R(crate::FieldReader<bool, bool>);
 impl ADD_RAW_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         ADD_RAW_R(crate::FieldReader::new(bits))
     }
@@ -187,6 +193,7 @@ impl<'a> ADD_RAW_W<'a> {
 #[doc = "Field `CROSS_RESULT` reader - If 1, feed the opposite lane's result into this lane's accumulator on POP."]
 pub struct CROSS_RESULT_R(crate::FieldReader<bool, bool>);
 impl CROSS_RESULT_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CROSS_RESULT_R(crate::FieldReader::new(bits))
     }
@@ -224,6 +231,7 @@ impl<'a> CROSS_RESULT_W<'a> {
  Takes effect even if ADD_RAW is set (the CROSS_INPUT mux is before the shift+mask bypass)"]
 pub struct CROSS_INPUT_R(crate::FieldReader<bool, bool>);
 impl CROSS_INPUT_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CROSS_INPUT_R(crate::FieldReader::new(bits))
     }
@@ -262,6 +270,7 @@ impl<'a> CROSS_INPUT_W<'a> {
  before adding to BASE0, and LANE0 PEEK/POP appear extended to 32 bits when read by processor."]
 pub struct SIGNED_R(crate::FieldReader<bool, bool>);
 impl SIGNED_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SIGNED_R(crate::FieldReader::new(bits))
     }
@@ -300,6 +309,7 @@ impl<'a> SIGNED_W<'a> {
  Setting MSB < LSB may cause chip to turn inside-out"]
 pub struct MASK_MSB_R(crate::FieldReader<u8, u8>);
 impl MASK_MSB_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         MASK_MSB_R(crate::FieldReader::new(bits))
     }
@@ -327,6 +337,7 @@ impl<'a> MASK_MSB_W<'a> {
 #[doc = "Field `MASK_LSB` reader - The least-significant bit allowed to pass by the mask (inclusive)"]
 pub struct MASK_LSB_R(crate::FieldReader<u8, u8>);
 impl MASK_LSB_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         MASK_LSB_R(crate::FieldReader::new(bits))
     }
@@ -353,6 +364,7 @@ impl<'a> MASK_LSB_W<'a> {
 #[doc = "Field `SHIFT` reader - Logical right-shift applied to accumulator before masking"]
 pub struct SHIFT_R(crate::FieldReader<u8, u8>);
 impl SHIFT_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         SHIFT_R(crate::FieldReader::new(bits))
     }
@@ -392,12 +404,17 @@ impl R {
     pub fn overf0(&self) -> OVERF0_R {
         OVERF0_R::new(((self.bits >> 23) & 0x01) != 0)
     }
-    #[doc = "Bit 22 - Only present on INTERP1 on each core. If CLAMP mode is enabled: - LANE0 result is shifted and masked ACCUM0, clamped by a lower bound of BASE0 and an upper bound of BASE1. - Signedness of these comparisons is determined by LANE0_CTRL_SIGNED"]
+    #[doc = "Bit 22 - Only present on INTERP1 on each core. If CLAMP mode is enabled:  
+ - LANE0 result is shifted and masked ACCUM0, clamped by a lower bound of  
+ BASE0 and an upper bound of BASE1.  
+ - Signedness of these comparisons is determined by LANE0_CTRL_SIGNED"]
     #[inline(always)]
     pub fn clamp(&self) -> CLAMP_R {
         CLAMP_R::new(((self.bits >> 22) & 0x01) != 0)
     }
-    #[doc = "Bits 19:20 - ORed into bits 29:28 of the lane result presented to the processor on the bus. No effect on the internal 32-bit datapath. Handy for using a lane to generate sequence of pointers into flash or SRAM."]
+    #[doc = "Bits 19:20 - ORed into bits 29:28 of the lane result presented to the processor on the bus.  
+ No effect on the internal 32-bit datapath. Handy for using a lane to generate sequence  
+ of pointers into flash or SRAM."]
     #[inline(always)]
     pub fn force_msb(&self) -> FORCE_MSB_R {
         FORCE_MSB_R::new(((self.bits >> 19) & 0x03) as u8)
@@ -412,17 +429,20 @@ impl R {
     pub fn cross_result(&self) -> CROSS_RESULT_R {
         CROSS_RESULT_R::new(((self.bits >> 17) & 0x01) != 0)
     }
-    #[doc = "Bit 16 - If 1, feed the opposite lane's accumulator into this lane's shift + mask hardware. Takes effect even if ADD_RAW is set (the CROSS_INPUT mux is before the shift+mask bypass)"]
+    #[doc = "Bit 16 - If 1, feed the opposite lane's accumulator into this lane's shift + mask hardware.  
+ Takes effect even if ADD_RAW is set (the CROSS_INPUT mux is before the shift+mask bypass)"]
     #[inline(always)]
     pub fn cross_input(&self) -> CROSS_INPUT_R {
         CROSS_INPUT_R::new(((self.bits >> 16) & 0x01) != 0)
     }
-    #[doc = "Bit 15 - If SIGNED is set, the shifted and masked accumulator value is sign-extended to 32 bits before adding to BASE0, and LANE0 PEEK/POP appear extended to 32 bits when read by processor."]
+    #[doc = "Bit 15 - If SIGNED is set, the shifted and masked accumulator value is sign-extended to 32 bits  
+ before adding to BASE0, and LANE0 PEEK/POP appear extended to 32 bits when read by processor."]
     #[inline(always)]
     pub fn signed(&self) -> SIGNED_R {
         SIGNED_R::new(((self.bits >> 15) & 0x01) != 0)
     }
-    #[doc = "Bits 10:14 - The most-significant bit allowed to pass by the mask (inclusive) Setting MSB < LSB may cause chip to turn inside-out"]
+    #[doc = "Bits 10:14 - The most-significant bit allowed to pass by the mask (inclusive)  
+ Setting MSB < LSB may cause chip to turn inside-out"]
     #[inline(always)]
     pub fn mask_msb(&self) -> MASK_MSB_R {
         MASK_MSB_R::new(((self.bits >> 10) & 0x1f) as u8)
@@ -439,12 +459,17 @@ impl R {
     }
 }
 impl W {
-    #[doc = "Bit 22 - Only present on INTERP1 on each core. If CLAMP mode is enabled: - LANE0 result is shifted and masked ACCUM0, clamped by a lower bound of BASE0 and an upper bound of BASE1. - Signedness of these comparisons is determined by LANE0_CTRL_SIGNED"]
+    #[doc = "Bit 22 - Only present on INTERP1 on each core. If CLAMP mode is enabled:  
+ - LANE0 result is shifted and masked ACCUM0, clamped by a lower bound of  
+ BASE0 and an upper bound of BASE1.  
+ - Signedness of these comparisons is determined by LANE0_CTRL_SIGNED"]
     #[inline(always)]
     pub fn clamp(&mut self) -> CLAMP_W {
         CLAMP_W { w: self }
     }
-    #[doc = "Bits 19:20 - ORed into bits 29:28 of the lane result presented to the processor on the bus. No effect on the internal 32-bit datapath. Handy for using a lane to generate sequence of pointers into flash or SRAM."]
+    #[doc = "Bits 19:20 - ORed into bits 29:28 of the lane result presented to the processor on the bus.  
+ No effect on the internal 32-bit datapath. Handy for using a lane to generate sequence  
+ of pointers into flash or SRAM."]
     #[inline(always)]
     pub fn force_msb(&mut self) -> FORCE_MSB_W {
         FORCE_MSB_W { w: self }
@@ -459,17 +484,20 @@ impl W {
     pub fn cross_result(&mut self) -> CROSS_RESULT_W {
         CROSS_RESULT_W { w: self }
     }
-    #[doc = "Bit 16 - If 1, feed the opposite lane's accumulator into this lane's shift + mask hardware. Takes effect even if ADD_RAW is set (the CROSS_INPUT mux is before the shift+mask bypass)"]
+    #[doc = "Bit 16 - If 1, feed the opposite lane's accumulator into this lane's shift + mask hardware.  
+ Takes effect even if ADD_RAW is set (the CROSS_INPUT mux is before the shift+mask bypass)"]
     #[inline(always)]
     pub fn cross_input(&mut self) -> CROSS_INPUT_W {
         CROSS_INPUT_W { w: self }
     }
-    #[doc = "Bit 15 - If SIGNED is set, the shifted and masked accumulator value is sign-extended to 32 bits before adding to BASE0, and LANE0 PEEK/POP appear extended to 32 bits when read by processor."]
+    #[doc = "Bit 15 - If SIGNED is set, the shifted and masked accumulator value is sign-extended to 32 bits  
+ before adding to BASE0, and LANE0 PEEK/POP appear extended to 32 bits when read by processor."]
     #[inline(always)]
     pub fn signed(&mut self) -> SIGNED_W {
         SIGNED_W { w: self }
     }
-    #[doc = "Bits 10:14 - The most-significant bit allowed to pass by the mask (inclusive) Setting MSB < LSB may cause chip to turn inside-out"]
+    #[doc = "Bits 10:14 - The most-significant bit allowed to pass by the mask (inclusive)  
+ Setting MSB < LSB may cause chip to turn inside-out"]
     #[inline(always)]
     pub fn mask_msb(&mut self) -> MASK_MSB_W {
         MASK_MSB_W { w: self }
